﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Windows.Controls;
using Telerik.Windows.Controls.DragDrop;
using System.Windows;

namespace SilverlightApplication11
{
	public partial class MainPage : UserControl
	{
		public static ObservableCollection<ApplicationInfo> GenerateApplicationInfos()
		{
			ObservableCollection<ApplicationInfo> data = new ObservableCollection<ApplicationInfo>();
			data.Add(new ApplicationInfo("/MyProject;component/Images/DragAndDrop/LargeIcons/Atom.png", "C.E.R.N.", "Large Collider"));
			data.Add(new ApplicationInfo("/MyProject;component/Images/DragAndDrop/LargeIcons/Brush.png", "Imagine Inc.", "Paintbrush"));
			data.Add(new ApplicationInfo("/MyProject;component/Images/DragAndDrop/LargeIcons/CalendarEvents.png", "Control AG", "Lively Calendar"));
			data.Add(new ApplicationInfo("/MyProject;component/Images/DragAndDrop/LargeIcons/CDBurn.png", "The CD Factory", "Fire Burning ROM"));
			data.Add(new ApplicationInfo("/MyProject;component/Images/DragAndDrop/LargeIcons/favorites.png", "Star Factory", "Fav Explorer"));
			data.Add(new ApplicationInfo("/MyProject;component/Images/DragAndDrop/LargeIcons/Connected.png", "Open Org", "IE Fox"));
			data.Add(new ApplicationInfo("/MyProject;component/Images/DragAndDrop/LargeIcons/ChartDot.png", "AA-AZ inc", "Charting"));
			data.Add(new ApplicationInfo("/MyProject;component/Images/DragAndDrop/LargeIcons/Games.png", "EB Games", "SuperPlay"));
			return data;
		}
		private ObservableCollection<ApplicationInfo> allApplications = GenerateApplicationInfos();
		private ObservableCollection<ApplicationInfo> myApplications = new ObservableCollection<ApplicationInfo>();


		public MainPage()
		{
			InitializeComponent();

			allApplicationsBox.ItemsSource = allApplications;
			myApplicationsBox.ItemsSource = myApplications;

			RadDragAndDropManager.AddDragQueryHandler(this, OnDragQuery);
			RadDragAndDropManager.AddDragInfoHandler(this, OnDragInfo);
			RadDragAndDropManager.AddDropQueryHandler(this, OnDropQuery);
			RadDragAndDropManager.AddDropInfoHandler(this, OnDropInfo);
		}

		// OnDragQuery event handler
		private void OnDragQuery(object sender, DragDropQueryEventArgs e)
		{
			if (e.Options.Status == DragStatus.DragQuery)
			{
				e.Options.Payload = allApplicationsBox.SelectedItem;

				var visual = new ContentControl
				{
					ContentTemplate = this.Resources["ApplicationDragTemplate"] as DataTemplate,
					Content = e.Options.Payload
				};

				e.Options.DragCue = visual;
			}

			e.QueryResult = true;
		}

		private void OnDragInfo(object sender, DragDropEventArgs e)
		{
			ListBoxItem listBoxItem = e.Options.Source as ListBoxItem;
			ListBox box = ItemsControl.ItemsControlFromItemContainer(listBoxItem) as ListBox;
			IList<ApplicationInfo> itemsSource = box.ItemsSource as IList<ApplicationInfo>;
			ApplicationInfo payload = e.Options.Payload as ApplicationInfo;
			if (e.Options.Status == DragStatus.DragComplete)
			{
				if (payload != null && itemsSource.Contains(payload))
				{
					itemsSource.Remove(payload);
				}
			}
		}

		private void OnDropInfo(object sender, DragDropEventArgs e)
		{
			ItemsControl box = e.Options.Destination as ItemsControl;
			IList<ApplicationInfo> itemsSource = box.ItemsSource as IList<ApplicationInfo>;
			ApplicationInfo payload = e.Options.Payload as ApplicationInfo;
			if (e.Options.Status == DragStatus.DropComplete)
				if (!itemsSource.Contains(payload))
					itemsSource.Add(payload);
		}

		private void OnDropQuery(object sender, DragDropQueryEventArgs e)
		{
			ItemsControl box = e.Options.Destination as ItemsControl;
			IList<ApplicationInfo> itemsSource = box.ItemsSource as IList<ApplicationInfo>;
			ApplicationInfo payload = e.Options.Payload as ApplicationInfo;
			e.QueryResult = payload != null && !itemsSource.Contains(payload);
		}
	}

	public class ApplicationInfo
	{
		public ApplicationInfo(string iconPath, string name, string author)
		{
			this.IconPath = iconPath;
			this.Name = name;
			this.Author = author;
		}
		public String IconPath
		{
			get;
			set;
		}
		public String Name
		{
			get;
			set;
		}
		public String Author
		{
			get;
			set;
		}
	}
}
